@@ -34,6 +34,8 @@ namespace Ui
 class DownloadItem;
 }
 
+class QDBusError;
+class QDBusMessage;
 class QListWidgetItem;
 class QWebEngineDownloadRequest;
 
@@ -77,6 +79,9 @@ private Q_SLOTS:
     void customContextMenuRequested(const QPoint &pos);
     void clear();
 
+    void dbusError(const QDBusError &error);
+    void dbusMessage(const QDBusMessage &message);
+
     void copyDownloadLink();
 
 private:
