@@ -67,26 +67,17 @@ QObject *QmlUserScripts::findScript(const QString &name) const
 {
     auto *qmlUserScript = new QmlUserScript();
 
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    QWebEngineScript webEngineScript = mApp->webProfile()->scripts()->findScript(name);
-    qmlUserScript->setWebEngineScript(webEngineScript);
-#else
     auto scripts = mApp->webProfile()->scripts()->find(name);
     if (!scripts.empty()) {
         qmlUserScript->setWebEngineScript(scripts.first());
     }
-#endif
 
     return qmlUserScript;
 }
 
 QList<QObject*> QmlUserScripts::findScripts(const QString &name) const
 {
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    QList<QWebEngineScript> list = mApp->webProfile()->scripts()->findScripts(name);
-#else
     QList<QWebEngineScript> list = mApp->webProfile()->scripts()->find(name);
-#endif
     return toQObjectList(list);
 }
 
