@@ -31,6 +31,7 @@
 #include <QCryptographicHash>
 #include <QNetworkReply>
 #include <QNetworkRequest>
+#include <QRegularExpression>
 
 GM_Script::GM_Script(GM_Manager* manager, const QString &filePath)
     : QObject(manager)
@@ -114,7 +115,7 @@ bool GM_Script::isEnabled() const
     return m_valid && m_enabled;
 }
 
-void GM_Script::setEnabled(bool enable)
+void GM_Script::setEnabled(const bool enable)
 {
     m_enabled = enable;
 }
@@ -175,6 +176,39 @@ void GM_Script::updateScript()
     downloadRequires();
 }
 
+bool GM_Script::match(const QUrl& url) const
+{
+    QString urlString = url.toString();
+
+    for (const auto &exclude : std::as_const(m_exclude)) {
+        QString wildcardExp = QRegularExpression::wildcardToRegularExpression(
+            exclude,
+            QRegularExpression::UnanchoredWildcardConversion
+        );
+        QRegularExpression re(wildcardExp,
+                              QRegularExpression::CaseInsensitiveOption);
+
+        if (re.match(urlString).hasMatch()) {
+            return false;
+        }
+    }
+
+    for (const auto &include : std::as_const(m_include)) {
+        QString wildcardExp = QRegularExpression::wildcardToRegularExpression(
+            include,
+            QRegularExpression::UnanchoredWildcardConversion
+        );
+        QRegularExpression re(wildcardExp,
+                              QRegularExpression::CaseInsensitiveOption);
+
+        if (re.match(urlString).hasMatch()) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
 void GM_Script::watchedFileChanged(const QString &file)
 {
     if (m_fileName == file) {
@@ -279,6 +313,9 @@ void GM_Script::parseScript()
             else if (value == QLatin1String("document-idle")) {
                 m_startAt = DocumentIdle;
             }
+            else if (value == QLatin1String("context-menu")) {
+                m_startAt = ContextMenu;
+            }
         }
         else if (key == QL1S("@icon")) {
             m_iconUrl = QUrl(value);
